@@ -5,6 +5,8 @@
 
 #include <Tui/ZDocument_p.h>
 
+#include <Tui/Utils_p.h>
+
 TUIWIDGETS_NS_START
 
 ZDocumentCursorPrivate::ZDocumentCursorPrivate(ZDocumentCursor *pub, ZDocumentPrivate *doc,
@@ -259,7 +261,7 @@ void ZDocumentCursor::moveCharacterLeft(bool extendSelection) {
         setPosition({lay.previousCursorPosition(currentCodeUnit, ZTextLayout::SkipCharacters), currentLine},
                     extendSelection);
     } else if (currentLine > 0) {
-        setPosition({p->doc->lines[currentLine - 1].chars.size(), currentLine - 1}, extendSelection);
+        setPosition({size2int(p->doc->lines[currentLine - 1].chars.size()), currentLine - 1}, extendSelection);
     } else {
         // here we update the selection and the vertical movemend position
         setPosition({currentCodeUnit, currentLine}, extendSelection);
@@ -289,7 +291,7 @@ void ZDocumentCursor::moveWordLeft(bool extendSelection) {
         setPosition({lay.previousCursorPosition(currentCodeUnit, ZTextLayout::SkipWords), currentLine},
                     extendSelection);
     } else if (currentLine > 0) {
-        setPosition({p->doc->lines[currentLine - 1].chars.size(), currentLine - 1}, extendSelection);
+        setPosition({size2int(p->doc->lines[currentLine - 1].chars.size()), currentLine - 1}, extendSelection);
     } else {
         // here we update the selection and the vertical movemend position
         setPosition({currentCodeUnit, currentLine}, extendSelection);
@@ -393,7 +395,7 @@ void ZDocumentCursor::moveToStartIndentedText(bool extendSelection) {
 void ZDocumentCursor::moveToEndOfLine(bool extendSelection) {
     auto *const p = tuiwidgets_impl();
     const auto [currentCodeUnit, currentLine] = position();
-    setPosition({p->doc->lines[currentLine].chars.size(), currentLine}, extendSelection);
+    setPosition({size2int(p->doc->lines[currentLine].chars.size()), currentLine}, extendSelection);
 }
 
 void ZDocumentCursor::moveToStartOfDocument(bool extendSelection) {
@@ -402,7 +404,7 @@ void ZDocumentCursor::moveToStartOfDocument(bool extendSelection) {
 
 void ZDocumentCursor::moveToEndOfDocument(bool extendSelection) {
     auto *const p = tuiwidgets_impl();
-    setPosition({p->doc->lines.last().chars.size(), p->doc->lines.size() - 1}, extendSelection);
+    setPosition({size2int(p->doc->lines.last().chars.size()), size2int(p->doc->lines.size()) - 1}, extendSelection);
 }
 
 ZDocumentCursor::Position ZDocumentCursor::position() const {
@@ -419,8 +421,8 @@ void ZDocumentCursor::setPosition(ZDocumentCursor::Position pos, bool extendSele
 
 void ZDocumentCursor::setPositionPreservingVerticalMovementColumn(ZDocumentCursor::Position pos, bool extendSelection) {
     auto *const p = tuiwidgets_impl();
-    auto cursorLine = std::max(std::min(pos.line, p->doc->lines.size() - 1), 0);
-    auto cursorCodeUnit = std::max(std::min(pos.codeUnit, p->doc->lines[cursorLine].chars.size()), 0);
+    auto cursorLine = std::max(std::min(pos.line, size2int(p->doc->lines.size() - 1)), 0);
+    auto cursorCodeUnit = std::max(std::min(pos.codeUnit, size2int(p->doc->lines[cursorLine].chars.size())), 0);
 
     // We are not allowed to jump between characters. Therefore, we go once to the left and again to the right.
     if (cursorCodeUnit > 0) {
@@ -449,8 +451,8 @@ ZDocumentCursor::Position ZDocumentCursor::anchor() const {
 
 void ZDocumentCursor::setAnchorPosition(ZDocumentCursor::Position pos) {
     auto *const p = tuiwidgets_impl();
-    auto anchorLine = std::max(std::min(pos.line, p->doc->lines.size() - 1), 0);
-    auto anchorCodeUnit = std::max(std::min(pos.codeUnit, p->doc->lines[anchorLine].chars.size()), 0);
+    auto anchorLine = std::max(std::min(pos.line, size2int(p->doc->lines.size()) - 1), 0);
+    auto anchorCodeUnit = std::max(std::min(pos.codeUnit, size2int(p->doc->lines[anchorLine].chars.size())), 0);
 
     // We are not allowed to jump between characters. Therefore, we go once to the left and again to the right.
     if (anchorCodeUnit > 0) {
