@@ -10,6 +10,8 @@
 
 #include <Tui/ZDocumentSnapshot.h>
 
+#include <Tui/Utils_p.h>
+
 TUIWIDGETS_NS_START
 
 
@@ -53,13 +55,13 @@ namespace {
                     i++;
                 } else {
                     // not valid utf16, replace so it doesn't break regex search
-                    buffer[i] = 0xFFFD;
+                    buffer[i] = u'\xFFFD';
                 }
             } else if (ch.isLowSurrogate()) {
                 // not valid utf16, replace so it doesn't break regex search
                 // this might be a surrogate escape but libpcre (used by QRegularExpression) can't work
                 // with surrogate escapes
-                buffer[i] = 0xFFFD;
+                buffer[i] = u'\xFFFD';
             }
         }
     }
@@ -199,11 +201,12 @@ namespace {
                                     i = found = -1;
                                 }
                             }
-                            if (found != -1)
+                            if (found != -1) {
                                 return ZDocumentFindAsyncResultNew({found, line},
-                                                                   {parts.last().size(), line + parts.size() - 1},
+                                                                   {size2int(parts.last().size()), line + size2int(parts.size()) - 1},
                                                                    snap.revision(),
                                                                    QRegularExpressionMatch{});
+                            }
                        }
                     }
                     found = -1;
@@ -361,8 +364,8 @@ namespace {
                     }
                     if (match.capturedLength() <= 0) continue;
                     if (match.capturedStart() <= searchAt - match.capturedLength()) {
-                        res = ZDocumentFindAsyncResultNew({match.capturedStart(), line},
-                                                          {match.capturedStart() + match.capturedLength(), line},
+                        res = ZDocumentFindAsyncResultNew({size2int(match.capturedStart()), line},
+                                                          {size2int(match.capturedStart() + match.capturedLength()), line},
                                                           snap.revision(),
                                                           match);
                         continue;
