@@ -42,11 +42,17 @@ ZColor ZPalette::getColor(ZWidget *targetWidget, ZImplicitSymbol x) {
     QList<const RuleDef*> rules;
 
     for (ZWidget *w : widgets) {
-        QSet<QString> widgetClasses = w->paletteClass().toSet();
+        QSet<QString> widgetClasses;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QStringList tmpPaletteClass = w->paletteClass();
+        widgetClasses = QSet<QString>(tmpPaletteClass.begin(), tmpPaletteClass.end());
+#else
+        widgetClasses = w->paletteClass().toSet();
+#endif
 
         const ZPalettePrivate &pal = *w->palette().tuiwidgets_pimpl_ptr;
 
-        for (const auto &rule : qAsConst(pal.rules)) {
+        for (const auto &rule : std::as_const(pal.rules)) {
             rules.append(&rule);
         }
 
@@ -58,8 +64,8 @@ ZColor ZPalette::getColor(ZWidget *targetWidget, ZImplicitSymbol x) {
             }
         }
 
-        for (auto &rs : qAsConst(matchingRulesByLen)) {
-            for (const RuleDef *r : qAsConst(rs)) {
+        for (auto &rs : std::as_const(matchingRulesByLen)) {
+            for (const RuleDef *r : std::as_const(rs)) {
                 for (const RuleCmd &cmd : r->cmds) {
                     if (cmd.type == Publish || w == targetWidget) {
                         if (defs.contains(cmd.reference)) {
