@@ -75,6 +75,7 @@ public:
     void deinitTerminalForInternalConnection();
     void pauseTerminalForInternalConnection();
     void unpauseTerminalForInternalConnection();
+    void updateSizeForInternalConnection();
 
     void internalConnection_integration_free();
     void internalConnection_integration_write(const char *data, int length);
@@ -105,6 +106,7 @@ public:
     CursorStyle terminalCursorStyle = CursorStyle::Unset;
     bool terminalCursorVisible = true;
     int terminalCursorR = -1, terminalCursorG = -1, terminalCursorB = -1;
+    int inlineHeight = 8;
     termpaint_integration integration;
     std::unique_ptr<QSocketNotifier> inputNotifier;
 
