@@ -10,6 +10,8 @@
 #include <Tui/ZPainter.h>
 #include <Tui/ZTextStyle.h>
 
+#include <Tui/Utils_p.h>
+
 
 TUIWIDGETS_NS_START
 
@@ -307,7 +309,7 @@ void ZTextLayout::layoutLine(int index, int width) {
                 // of ascii spaces should count as a break opportunity as well.
                 return;
             }
-            QTextBoundaryFinder bndFinder(QTextBoundaryFinder::Line, p->text.data() + run.offset, std::max(offset + 2 /* allow for surrogate */, p->text.size()) - run.offset);
+            QTextBoundaryFinder bndFinder(QTextBoundaryFinder::Line, p->text.data() + run.offset, std::max(offset + 2 /* allow for surrogate */, size2int(p->text.size())) - run.offset);
             bndFinder.setPosition(offset - run.offset);
             int boundary = bndFinder.isAtBoundary() ? bndFinder.position() : bndFinder.toPreviousBoundary();
             if (boundary != -1 && run.offset + boundary != ld.offset) {
@@ -368,7 +370,7 @@ void ZTextLayout::layoutLine(int index, int width) {
             run.x = column;
             if (p->textOption.tabs().size()) {
                 auto tabs = p->textOption.tabs();
-                for (const ZTextOption::Tab &tab: qAsConst(tabs)) {
+                for (const ZTextOption::Tab &tab: std::as_const(tabs)) {
                     if (tab.position > column) {
                         column = tab.position;
                         break;
@@ -764,9 +766,9 @@ void ZTextLineRef::draw(ZPainter painter, const QPoint &pos, ZTextStyle color, Z
             } else if (run.type == ZTextLayoutPrivate::TextRun::SPACES) {
                 // only generated with ShowTabsAndSpaces or ShowTabsAndSpacesWithColors active
                 ZTextStyle style = formattingChars;
-                QChar ch = U' ';
+                QChar ch = u' ';
                 if (textOptionFlags & ZTextOption::ShowTabsAndSpaces) {
-                    ch = U'·';
+                    ch = u'·';
                 }
                 bool highlightingTrailingWhitespace = false;
                 if (textOptionFlags & ZTextOption::ShowTabsAndSpacesWithColors) {
